|
From: Keith M. <no...@so...> - 2017-05-24 22:15:46
|
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Repository: mingw-org-wsl".
The branch, 5.0-active has been updated
via 40982dff81a3c1dc0572cf2cd0a23156661ae98d (commit)
via 127b4a136978d1fd30a69fe7dac78a37da0ca667 (commit)
via 324d60b72dd9886d75db913335f2fa36fab093c6 (commit)
from ddc8f81e4256cd01807ec822b8ec458143473156 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
https://sf.net/p/mingw/mingw-org-wsl/ci/40982dff81a3c1dc0572cf2cd0a23156661ae98d/
commit 40982dff81a3c1dc0572cf2cd0a23156661ae98d
Author: Keith Marshall <kei...@us...>
Date: Wed May 24 23:11:33 2017 +0100
Fix snprintf()/vsnprintf() -Wformat vs. multiple definition issue.
diff --git a/mingwrt/ChangeLog b/mingwrt/ChangeLog
index e3f2881..2765231 100644
--- a/mingwrt/ChangeLog
+++ b/mingwrt/ChangeLog
@@ -1,3 +1,25 @@
+2017-05-24 Keith Marshall <kei...@us...>
+
+ Fix snprintf()/vsnprintf() -Wformat vs. multiple definition issue.
+
+ * include/stdio.h (__mingw_stdio_redirect__): Add reference to...
+ (__Wformat): ...this new macro; define it, such that it expands via...
+ (__Wformat_mingw_printf, __Wformat_msvcrt_printf): ...these new macros,
+ ultimately expanding to an attribute declaration, in terms of...
+ (__Wformat_ms_vprintf, __Wformat_ms_vfprintf, __Wformat_ms_vsprintf)
+ (__Wformat_ms_printf, __Wformat_ms_fprintf, __Wformat_ms_sprintf):
+ ...any one of these; they map to an ms_printf attribute, or...
+ (__Wformat_vprintf, __Wformat_vfprintf, __Wformat_vsprintf)
+ (__Wformat_printf, __Wformat_fprintf, __Wformat_sprintf): ...any one
+ of these; they map conditionally to...
+ [__GNUC__>=6] (__mingw_printf__): ...this new format attribute, or...
+ [__GNUC__< 6]: ...nothing.
+ (snprintf, vsnprintf): Revert 2017-01-30 inline definitions; add...
+ (__Wformat_snprintf, __Wformat_vsnprintf): ...these attributes; they
+ are also mapped conditionally, in this case to...
+ [__GNUC__>=6] (__mingw_printf__): ...this, or...
+ [__GNUC__< 6] (__gnu_printf__): ...this.
+
2017-03-14 Keith Marshall <kei...@us...>
Refactor mingwrt and w32api common makefile content.
diff --git a/ChangeLog b/ChangeLog
index ccc46c0..1c4bdc3 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,15 @@
+2017-03-14 Keith Marshall <kei...@us...>
+
+ Refactor mingwrt and w32api common makefile content.
+
+ * Makefile.comm: New file.
+ (COMMON_MAKEFILE): New macro; define it to identify this file.
+ (%-srcdist-common-files): New generic build rule; implement it.
+ (configure, config.status, Makefile, config.status.missing, _mingw.h)
+ (w32api.h, PACKAGE_VERSION_SCRIPT, PACKAGE_VERSION_FORMAT): Reproduce
+ the original common content, which has been factored out from...
+ * mingwrt/Makefile.in w32api/Makefile.in: ...here.
+
2017-03-09 Keith Marshall <kei...@us...>
MinGW.org WSL-5.0 released; update repository version.
diff --git a/Makefile.comm b/Makefile.comm
new file mode 100644
index 0000000..af83ded
--- /dev/null
+++ b/Makefile.comm
@@ -0,0 +1,106 @@
+# Makefile.comm
+#
+# Common elements, shared by the subpackage makefiles for each of the
+# MinGW.org Runtime Library and Windows-32 API packages.
+#
+# $Id$
+#
+# Written by Keith Marshall <kei...@us...>
+# Copyright (C) 2017, MinGW.org Project
+#
+#
+# Permission is hereby granted, free of charge, to any person obtaining a
+# copy of this software and associated documentation files (the "Software"),
+# to deal in the Software without restriction, including without limitation
+# the rights to use, copy, modify, merge, publish, distribute, sublicense,
+# and/or sell copies of the Software, and to permit persons to whom the
+# Software is furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice (including the next
+# paragraph) shall be included in all copies or substantial portions of the
+# Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
+
+
+# Note whence we are reading this makefile fragment, so that we may
+# access it again, for inclusion in source distributions.
+#
+COMMON_MAKEFILE := $(lastword $(MAKEFILE_LIST))
+
+# Configuration
+# -------------
+#
+# Keep the configuration in a consistent state. Note that we assume
+# that configure has been run initially, (otherwise we wouldn't have
+# a Makefile to begin with); since this also creates config.status,
+# we may normally assume that it is already available ...
+#
+vpath configure ${top_srcdir}
+config.status: configure
+ $(SHELL) config.status --recheck
+
+# ... in which case, updating Makefile should be a simple matter of
+# running config.status ...
+#
+vpath Makefile.in ${top_srcdir}
+requires_existing = $(if $(wildcard $1),$1,$1.missing)
+Makefile: Makefile.in configure $(call requires_existing,config.status)
+ $(SHELL) config.status
+ $(RM) Makefile.stub
+
+.PHONY: config.status.missing
+# ... but, in the event that this may be missing, (e.g. because it
+# has been manually removed, or removed by "make distclean"), suggest
+# running configure, and bail out.
+#
+config.status.missing:
+ $(warning *** cannot execute config.status)
+ $(error please run ${top_srcdir}/configure to regenerate it.)
+
+# If configure itself needs to be updated, we must run autoconf in the
+# respective top level source directory.
+#
+vpath configure.ac ${top_srcdir}
+vpath %.m4 ${top_srcdir}/.. ${top_srcdir}
+configure: configure.ac aclocal.m4 VERSION.m4
+ cd ${top_srcdir}; autoconf -I ..
+
+# Propagate package version, as configured, consistently throughout
+# the package build; in particular, we must generate the _mingw.h and
+# w32api.h header files, from their respective templates with each of
+# the package version macro definitions completed.
+#
+vpath %.h.in ${mingwrt_srcdir}/include ${w32api_srcdir}/include
+
+_mingw.h w32api.h: %.h: %.h.in VERSION.m4
+ $(PACKAGE_VERSION_SCRIPT) $< > $@
+
+PACKAGE_VERSION_SCRIPT = sed \
+ -e s"`$(call PACKAGE_VERSION_FORMAT,LONG,%d,$$3+1000*($$2+1000*$$1))`" \
+ -e s"`$(call PACKAGE_VERSION_FORMAT,MAJOR,%7d,$$1)`" \
+ -e s"`$(call PACKAGE_VERSION_FORMAT,MINOR,%7d,$$2)`" \
+ -e s"`$(call PACKAGE_VERSION_FORMAT,PATCH,%7d,$$3)`"
+
+PACKAGE_VERSION_FORMAT = echo $(PACKAGE_VERSION).0.0 | awk -F. '{ \
+ printf ",%%PACKAGE_VERSION_$1%%,$2,", $3; \
+}'
+
+
+# Distribution
+# ------------
+#
+# Propagate common source files to individual subpackage source
+# distribution tarballs.
+#
+vpath install-sh ${top_srcdir}/.. ${top_srcdir}
+%-srcdist-common-files: $(COMMON_MAKEFILE) VERSION.m4 aclocal.m4 install-sh
+ cp -p $^ dist/$(PACKAGE_TARNAME)-$(PACKAGE_VERSION)
+
+# $RCSfile$: end of file
diff --git a/mingwrt/ChangeLog b/mingwrt/ChangeLog
index 2051e3c..e3f2881 100644
--- a/mingwrt/ChangeLog
+++ b/mingwrt/ChangeLog
@@ -1,3 +1,15 @@
+2017-03-14 Keith Marshall <kei...@us...>
+
+ Refactor mingwrt and w32api common makefile content.
+
+ * Makefile.in (mingwrt-srcdist-config-files): Rename it...
+ (mingwrt-srcdist-common-files): ...as this phoney build rule.
+ (shared_include_file): New macro; define it, and include named file.
+ (configure, config.status, Makefile, config.status.missing, _mingw.h)
+ (w32api.h, PACKAGE_VERSION_SCRIPT, PACKAGE_VERSION_FORMAT): Factor
+ out; relocate them to new file in common parent directory...
+ * ../Makefile.comm: ...here.
+
2017-03-09 Keith Marshall <kei...@us...>
Fix generated header file dependencies.
diff --git a/mingwrt/Makefile.in b/mingwrt/Makefile.in
index e9bcee2..7e2be61 100644
--- a/mingwrt/Makefile.in
+++ b/mingwrt/Makefile.in
@@ -107,59 +107,13 @@ INSTALL_DATA = @INSTALL_DATA@ $1 $2
mkinstalldirs = @MKDIR_P@ $(addprefix $1,$2)
LN_S = @LN_S@
-# Keep the configuration in a consistent state. Note that we assume
-# that configure has been run initially, (otherwise we wouldn't have
-# a Makefile to begin with); since this also creates config.status,
-# we may normally assume that it is already available ...
+# Include the makefile content which is common to both the mingwrt,
+# and the w32api packages; this may be included within the top level
+# source directory for each package individually, but we must also
+# be prepared to find it in their common parent directory.
#
-vpath configure ${top_srcdir}
-config.status: configure
- $(SHELL) config.status --recheck
-
-# ... in which case, updating Makefile should be a simple matter of
-# running config.status ...
-#
-vpath Makefile.in ${top_srcdir}
-requires_existing = $(if $(wildcard $1),$1,$1.missing)
-Makefile: Makefile.in configure $(call requires_existing,config.status)
- $(SHELL) config.status
- $(RM) Makefile.stub
-
-.PHONY: config.status.missing
-# ... but, in the event that this may be missing, (e.g. because it
-# has been manually removed, or removed by "make distclean"), suggest
-# running configure, and bail out.
-#
-config.status.missing:
- $(warning *** cannot execute config.status)
- $(error please run ${top_srcdir}/configure to regenerate it.)
-
-# If configure itself needs to be updated, we must run autoconf in the
-# top level source directory.
-#
-vpath configure.ac ${top_srcdir}
-vpath %.m4 ${top_srcdir}/.. ${top_srcdir}
-configure: configure.ac aclocal.m4 VERSION.m4
- cd ${top_srcdir}; autoconf -I ..
-
-# Propagate package version, as configured, consistently throughout
-# the package build.
-#
-vpath _mingw.h.in ${top_srcdir}/include
-vpath w32api.h.in ${w32api_srcdir}/include
-
-_mingw.h w32api.h: %.h: %.h.in VERSION.m4
- $(PACKAGE_VERSION_SCRIPT) $< > $@
-
-PACKAGE_VERSION_SCRIPT = sed \
- -e s"`$(call PACKAGE_VERSION_FORMAT,LONG,%d,$$3+1000*($$2+1000*$$1))`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,MAJOR,%7d,$$1)`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,MINOR,%7d,$$2)`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,PATCH,%7d,$$3)`"
-
-PACKAGE_VERSION_FORMAT = echo $(PACKAGE_VERSION).0.0 | awk -F. '{ \
- printf ",%%PACKAGE_VERSION_$1%%,$2,", $3; \
-}'
+shared_include_file = $1$(if $(wildcard $1/$2),,/..)/$2
+include $(call shared_include_file,${top_srcdir},Makefile.comm)
# Capture dependencies conveyed within source files, ensuring that
# header files are taken from our working source tree, and not from
@@ -986,14 +940,10 @@ mingwrt-srcdist-dir:
$(RM) -r dist/$(PACKAGE_TARNAME)-$(PACKAGE_VERSION)
$(call mkinstalldirs,,dist/$(PACKAGE_TARNAME)-$(PACKAGE_VERSION))
-mingwrt-srcdist-files: mingwrt-srcdist-config-files
+mingwrt-srcdist-files: mingwrt-srcdist-common-files
mingwrt-srcdist-files: mingwrt-srcdist-testsuite-files
mingwrt-srcdist-files: mingwrt-srcdist-package-files
-vpath install-sh ${top_srcdir}/.. ${top_srcdir}
-mingwrt-srcdist-config-files: aclocal.m4 VERSION.m4 install-sh
- cp -p $^ dist/$(PACKAGE_TARNAME)-$(PACKAGE_VERSION)
-
mingwrt-srcdist-package-files:
(cd ${mingwrt_srcdir} && tar chf - --hard-dereference $(notdir $^)) | \
(cd dist/$(PACKAGE_TARNAME)-$(PACKAGE_VERSION) && tar xf -)
diff --git a/w32api/ChangeLog b/w32api/ChangeLog
index 1c7976d..888d825 100644
--- a/w32api/ChangeLog
+++ b/w32api/ChangeLog
@@ -1,3 +1,15 @@
+2017-03-14 Keith Marshall <kei...@us...>
+
+ Refactor mingwrt and w32api common makefile content.
+
+ * Makefile.in (w32api-srcdist-config-files): Rename it...
+ (w32api-srcdist-common-files): ...as this phoney build rule.
+ (shared_include_file): New macro; define it, and include named file.
+ (configure, config.status, Makefile, config.status.missing, _mingw.h)
+ (w32api.h, PACKAGE_VERSION_SCRIPT, PACKAGE_VERSION_FORMAT): Factor
+ out; relocate them to new file in common parent directory...
+ * ../Makefile.comm: ...here.
+
2017-03-12 Keith Marshall <kei...@us...>
Correct a copyright notice update omission.
diff --git a/w32api/Makefile.in b/w32api/Makefile.in
index 2ee7204..ba39f7b 100644
--- a/w32api/Makefile.in
+++ b/w32api/Makefile.in
@@ -80,57 +80,13 @@ INSTALL = @INSTALL@
INSTALL_DATA = @INSTALL_DATA@ $1 $2
LN_S = @LN_S@
-# Keep the configuration in a consistent state. Note that we assume
-# that configure has been run initially, (otherwise we wouldn't have
-# a Makefile to begin with); since this also creates config.status,
-# we may normally assume that it is already available ...
+# Include the makefile content which is common to both the mingwrt,
+# and the w32api packages; this may be included within the top level
+# source directory for each package individually, but we must also
+# be prepared to find it in their common parent directory.
#
-vpath configure ${top_srcdir}
-config.status: configure
- $(SHELL) config.status --recheck
-
-# ... in which case, updating Makefile should be a simple matter of
-# running config.status ...
-#
-vpath Makefile.in ${top_srcdir}
-requires_existing = $(if $(wildcard $1),$1,$1.missing)
-Makefile: Makefile.in configure $(call requires_existing,config.status)
- $(SHELL) config.status
-
-.PHONY: config.status.missing
-# ... but, in the event that this may be missing, (e.g. because it
-# has been manually removed, or removed by "make distclean"), suggest
-# running configure, and bail out.
-#
-config.status.missing:
- $(warning *** cannot execute config.status)
- $(error please run ${top_srcdir}/configure to regenerate it.)
-
-# If configure itself needs to be updated, we must run autoconf in the
-# top level source directory.
-#
-vpath configure.ac ${top_srcdir}
-vpath %.m4 ${top_srcdir}/.. ${top_srcdir}
-configure: configure.ac aclocal.m4 VERSION.m4
- cd ${top_srcdir}; autoconf -I ..
-
-# Propagate package version, as configured, consistently throughout
-# the package build.
-#
-vpath %.h.in ${top_srcdir}/include ${mingwrt_srcdir}/include
-
-w32api.h _mingw.h: %.h: %.h.in VERSION.m4
- $(PACKAGE_VERSION_SCRIPT) $< > $@
-
-PACKAGE_VERSION_SCRIPT = sed \
- -e s"`$(call PACKAGE_VERSION_FORMAT,LONG,%d,$$3+1000*($$2+1000*$$1))`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,MAJOR,%7d,$$1)`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,MINOR,%7d,$$2)`" \
- -e s"`$(call PACKAGE_VERSION_FORMAT,PATCH,%7d,$$3)`"
-
-PACKAGE_VERSION_FORMAT = echo $(PACKAGE_VERSION).0.0 | awk -F. '{ \
- printf ",%%PACKAGE_VERSION_$1%%,$2,", $3; \
-}'
+shared_include_file = $1$(if $(wildcard $1/$2),,/..)/$2
+include $(call shared_include_file,${top_srcdir},Makefile.comm)
# Capture dependencies conveyed within source files, ensuring that
# header files are taken from our working source tree, and not from
@@ -362,14 +318,10 @@ mingwrt-srcdist-dir w32api-srcdist-dir: %-srcdist-dir:
$(RM) -r dist/$*-$(PACKAGE_VERSION)
$(call mkinstalldirs,,dist/$*-$(PACKAGE_VERSION))
-w32api-srcdist-files: w32api-srcdist-config-files
+w32api-srcdist-files: w32api-srcdist-common-files
w32api-srcdist-files: w32api-srcdist-testsuite-files
w32api-srcdist-files: w32api-srcdist-package-files
-vpath install-sh ${top_srcdir}/.. ${top_srcdir}
-%-srcdist-config-files: aclocal.m4 VERSION.m4 install-sh
- cp -p $^ dist/$*-$(PACKAGE_VERSION)
-
%-srcdist-package-files:
(cd ${$*_srcdir} && tar chf - --hard-dereference $(notdir $^)) | \
(cd dist/$*-$(PACKAGE_VERSION) && tar xf -)
https://sf.net/p/mingw/mingw-org-wsl/ci/324d60b72dd9886d75db913335f2fa36fab093c6/
commit 324d60b72dd9886d75db913335f2fa36fab093c6
Author: Keith Marshall <kei...@us...>
Date: Sun Mar 12 09:23:34 2017 +0000
Correct a copyright notice update omission.
diff --git a/w32api/ChangeLog b/w32api/ChangeLog
index fd2bc27..1c7976d 100644
--- a/w32api/ChangeLog
+++ b/w32api/ChangeLog
@@ -1,3 +1,10 @@
+2017-03-12 Keith Marshall <kei...@us...>
+
+ Correct a copyright notice update omission.
+
+ * configure.ac: Extend copyright date range to include 2017. Also
+ clean up superfluous trailing whitespace.
+
2017-03-09 Keith Marshall <kei...@us...>
Fix generated header file dependencies.
diff --git a/w32api/configure.ac b/w32api/configure.ac
index 2dac7bd..c7c5315 100644
--- a/w32api/configure.ac
+++ b/w32api/configure.ac
@@ -6,7 +6,7 @@
# $Id$
#
# Written by Keith Marshall <kei...@us...>
-# Copyright (C) 2015, 2016, MinGW.org Project
+# Copyright (C) 2015-2017, MinGW.org Project
#
#
# Permission is hereby granted, free of charge, to any person obtaining a
@@ -15,11 +15,11 @@
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
-#
+#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
-#
+#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-----------------------------------------------------------------------
Summary of changes:
ChangeLog | 12 +++++++
Makefile.in => Makefile.comm | 82 +++++++++++++++++-------------------------
mingwrt/ChangeLog | 34 ++++++++++++++++++
mingwrt/Makefile.in | 64 ++++-----------------------------
mingwrt/include/stdio.h | 84 +++++++++++++++++++++++++++++++-------------
w32api/ChangeLog | 19 ++++++++++
w32api/Makefile.in | 62 ++++----------------------------
w32api/configure.ac | 6 ++--
8 files changed, 175 insertions(+), 188 deletions(-)
copy Makefile.in => Makefile.comm (60%)
hooks/post-receive
diff --git a/mingwrt/include/stdio.h b/mingwrt/include/stdio.h
index e17afa0..ab03057 100644
--- a/mingwrt/include/stdio.h
+++ b/mingwrt/include/stdio.h
@@ -298,10 +298,46 @@ _CRTIMP __cdecl __MINGW_NOTHROW void setbuf (FILE *, char *);
/* Formatted Output
*
* MSVCRT implementations are not ANSI C99 conformant...
- * we offer these conforming alternatives from libmingwex.a
+ * we offer conforming alternatives from libmingwex.a
*/
#undef __mingw_stdio_redirect__
-#define __mingw_stdio_redirect__(F) __cdecl __MINGW_NOTHROW __mingw_##F
+#define __mingw_stdio_redirect__(F) __cdecl __MINGW_NOTHROW __Wformat(F)
+#define __Wformat_mingw_printf(F,A) __attribute__((__format__(__mingw_printf__,F,A)))
+
+#if __GNUC__ >= 6
+/* From GCC-6 onwards, we will provide customized -Wformat
+ * handling, via our own mingw_printf format category...
+ */
+#define __Wformat(F) __Wformat_##F __mingw_##F
+
+#else /* __GNUC__ < 6 */
+/* ...whereas, for earlier GCC, we preserve the status quo,
+ * offering no -Wformat checking for those functions which
+ * replace the MSVCRT.DLL versions...
+ */
+#define __Wformat(F) __mingw_##F
+/*
+ * ...while degrading to gnu_printf checking for snprintf()
+ * and vsnprintf(), (which are ALWAYS MinGW.org variants).
+ */
+#define __mingw_printf__ __gnu_printf__
+#endif
+
+/* The following convenience macros specify the appropriate
+ * -Wformat checking for MSVCRT.DLL replacement functions...
+ */
+#define __Wformat_printf __Wformat_mingw_printf(1,2)
+#define __Wformat_fprintf __Wformat_mingw_printf(2,3)
+#define __Wformat_sprintf __Wformat_mingw_printf(2,3)
+#define __Wformat_vprintf __Wformat_mingw_printf(1,0)
+#define __Wformat_vfprintf __Wformat_mingw_printf(2,0)
+#define __Wformat_vsprintf __Wformat_mingw_printf(2,0)
+/*
+ * ...while this pair are specific to the two MinGW.org
+ * only functions.
+ */
+#define __Wformat_snprintf __Wformat_mingw_printf(3,4)
+#define __Wformat_vsnprintf __Wformat_mingw_printf(3,0)
extern int __mingw_stdio_redirect__(fprintf)(FILE*, const char*, ...);
extern int __mingw_stdio_redirect__(printf)(const char*, ...);
@@ -394,16 +430,6 @@ int sprintf (char *__stream, const char *__format, ...)
}
__mingw_stdio_redirect__
-int snprintf (char *__stream, size_t __len, const char *__format, ...)
-{
- register int __retval;
- __builtin_va_list __local_argv; __builtin_va_start( __local_argv, __format );
- __retval = __mingw_vsnprintf( __stream, __len, __format, __local_argv );
- __builtin_va_end( __local_argv );
- return __retval;
-}
-
-__mingw_stdio_redirect__
int vfprintf (FILE *__stream, const char *__format, __VALIST __local_argv)
{
return __mingw_vfprintf( __stream, __format, __local_argv );
@@ -421,13 +447,7 @@ int vsprintf (char *__stream, const char *__format, __VALIST __local_argv)
return __mingw_vsprintf( __stream, __format, __local_argv );
}
-__mingw_stdio_redirect__
-int vsnprintf (char *__stream, size_t __len, const char *__format, __VALIST __local_argv)
-{
- return __mingw_vsnprintf( __stream, __len, __format, __local_argv );
-}
-
-#else
+#else /* !__USE_MINGW_ANSI_STDIO */
/* Default configuration: simply direct all calls to MSVCRT...
*/
_CRTIMP __cdecl __MINGW_NOTHROW int fprintf (FILE *, const char *, ...);
@@ -439,10 +459,21 @@ _CRTIMP __cdecl __MINGW_NOTHROW int vsprintf (char *, const char *, __VALIST);
#endif
/* Regardless of user preference, always offer these alternative
* entry points, for direct access to the MSVCRT implementations.
*/
+#undef __Wformat
#undef __mingw_stdio_redirect__
-#define __mingw_stdio_redirect__(F) __cdecl __MINGW_NOTHROW __msvcrt_##F
+#define __mingw_stdio_redirect__(F) __cdecl __MINGW_NOTHROW __Wformat(F)
+#define __Wformat_msvcrt_printf(F,A) __attribute__((__format__(__ms_printf__,F,A)))
+#define __Wformat(F) __Wformat_ms_##F __msvcrt_##F
+
+#define __Wformat_ms_printf __Wformat_msvcrt_printf(1,2)
+#define __Wformat_ms_fprintf __Wformat_msvcrt_printf(2,3)
+#define __Wformat_ms_sprintf __Wformat_msvcrt_printf(2,3)
+#define __Wformat_ms_vprintf __Wformat_msvcrt_printf(1,0)
+#define __Wformat_ms_vfprintf __Wformat_msvcrt_printf(2,0)
+#define __Wformat_ms_vsprintf __Wformat_msvcrt_printf(2,0)
_CRTIMP int __mingw_stdio_redirect__(fprintf)(FILE *, const char *, ...);
_CRTIMP int __mingw_stdio_redirect__(printf)(const char *, ...);
@@ -452,6 +483,7 @@ _CRTIMP int __mingw_stdio_redirect__(vprintf)(const char *, __VALIST);
_CRTIMP int __mingw_stdio_redirect__(vsprintf)(char *, const char *, __VALIST);
#undef __mingw_stdio_redirect__
+#undef __Wformat
/* The following three ALWAYS refer to the MSVCRT implementations...
*/
@@ -466,10 +498,14 @@ _CRTIMP __cdecl __MINGW_NOTHROW int _vscprintf (const char *, __VALIST);
* NOT compatible with C99, but the following are; if you want the
* MSVCRT behaviour, you MUST use the Microsoft "uglified" names.
*/
-__cdecl __MINGW_NOTHROW int snprintf (char *, size_t, const char *, ...);
-__cdecl __MINGW_NOTHROW int vsnprintf (char *, size_t, const char *, __VALIST);
+__cdecl __MINGW_NOTHROW __Wformat_snprintf
+int snprintf (char *, size_t, const char *, ...);
+
+__cdecl __MINGW_NOTHROW __Wformat_vsnprintf
+int vsnprintf (char *, size_t, const char *, __VALIST);
-__cdecl __MINGW_NOTHROW int vscanf (const char * __restrict__, __VALIST);
+__cdecl __MINGW_NOTHROW
+int vscanf (const char * __restrict__, __VALIST);
__cdecl __MINGW_NOTHROW
int vfscanf (FILE * __restrict__, const char * __restrict__, __VALIST);
https://sf.net/p/mingw/mingw-org-wsl/ci/127b4a136978d1fd30a69fe7dac78a37da0ca667/
@@ -439,10 +459,21 @@ _CRTIMP __cdecl __MINGW_NOTHROW int vsprintf (char *, const char *, __VALIST);
#endif
/* Regardless of user preference, always offer these alternative
- * entry points, for direct access to the MSVCRT implementations.
+ * entry points, for direct access to the MSVCRT implementations,
+ * with ms_printf -Wformat checking in each case.
*/
commit 127b4a136978d1fd30a69fe7dac78a37da0ca667
Author: Keith Marshall <kei...@us...>
Date: Tue Mar 14 16:24:00 2017 +0000
Refactor mingwrt and w32api common makefile content.
--
Repository: mingw-org-wsl
|